@@ -624,7 +624,7 @@ class Raster(_RasterBase):
 
     @property
     def data(self):
-        """The underlying dask array of data"""
+        """The underlying dask array of data (read only)"""
         return self._ds.raster.data
 
     @property
