@@ -9,6 +9,7 @@ import geopandas as gpd
 import numpy as np
 import pandas as pd
 import rasterio as rio
+import shapely
 import xarray as xr
 from dask.delayed import delayed
 from packaging import version
@@ -231,6 +232,25 @@ def get_vector(src):
         raise TypeError("Invalid vector input")
 
 
+def get_vector_frame(src):
+    if isinstance(src, Vector):
+        return src.data
+    elif is_str(src):
+        result = open_vectors(src)
+        if not isinstance(result, Vector):
+            # More than one layer was found
+            raise ValueError("Input source must only have 1 layer")
+        return result.data
+    elif _is_series(src) or _is_frame(src):
+        if _is_series(src):
+            src = src.to_frame("geometry")
+        if dask.is_dask_collection(src):
+            return src
+        return dgpd.from_geopandas(src, npartitions=1)
+    else:
+        raise TypeError("Invalid vector input")
+
+
 def _get_len_from_divisions(divs):
     # This should never overcount but may undercount by 1 because
     # dask.dataframe special cases the last division when creating a dataframe.
@@ -424,8 +444,20 @@ def _vector_to_raster_dask(df, size, xlike, field=None, all_touched=True):
 def _geoms_to_raster_mask(xc, yc, geoms, all_touched=True, block_info=None):
     xc = xc.ravel()
     yc = yc.ravel()
-    # Convert geoms into a boolean (0/1) array using xc and yc for gridding.
     shape = (yc.size, xc.size)
+    cell_size = max(np.diff(xc).max(), np.diff(yc).max())
+    chunk_bbox = shapely.geometry.box(
+        xc.min(), yc.min(), xc.max(), yc.max()
+    ).buffer(cell_size)
+    geoms_bbox = shapely.geometry.box(*geoms.total_bounds)
+    if not shapely.intersects(chunk_bbox, geoms_bbox):
+        return np.zeros(shape, dtype="uint8")
+
+    geoms = geoms.clip(chunk_bbox)
+    if not len(geoms):
+        return np.zeros(shape, dtype="uint8")
+
+    # Convert geoms into a boolean (0/1) array using xc and yc for gridding.
     transform = xr.DataArray(
         da.zeros(shape), coords=(yc, xc), dims=("y", "x")
     ).rio.transform()
@@ -462,7 +494,7 @@ def _vector_to_raster_mask(geoms, like, all_touched=True):
             meta=np.array((), dtype=I8),
         )
         parts.append(data)
-    data = da.stack(parts, axis=0).max(axis=0, keepdims=True)
+    data = da.stack(parts, axis=0).any(axis=0, keepdims=True).astype("uint8")
     x = like.x
     y = like.y
     xrs = xr.DataArray(data, coords=([1], y, x), dims=like.xdata.dims)
@@ -472,6 +504,82 @@ def _vector_to_raster_mask(geoms, like, all_touched=True):
     return xrs
 
 
+def rasterize(gdf, like, field=None, all_touched=True):
+    """Convert vector data to a raster.
+
+    Parameters
+    ----------
+    like : Raster
+        A to use for grid and CRS information. The resulting raster will be
+        on the same grid as `like`.
+    field : str, optional
+        The name of a field to use for fill values when rasterizing the
+        vector features.
+    all_touched : bool, optional
+        If ``True``, grid cells that the vector touches will be burned in.
+        If False, only cells with a center point inside of the vector
+        perimeter will be burned in.
+
+    Returns
+    -------
+    Raster
+        The resulting raster. The result will have a single band. Each
+        vector shape is assigned a 1-based integer value equal to its order
+        in the original vector collection. This integer value is what is
+        burned in at the corresponding grid cells. The dtype of the result
+        will be the minimum, unsigned integer type that can fit the ID
+        values. The null value is 0.
+
+    """
+    like = get_raster(like)
+    if field is not None:
+        if not is_str(field):
+            raise TypeError("Field must be a string")
+        if field not in gdf:
+            raise ValueError(f"Invalid field name: {repr(field)}")
+        dtype = gdf.dtypes.to_dict()[field]
+        if not is_int(dtype) and not is_float(dtype):
+            raise ValueError("The specified field must be a scalar data type")
+
+    xrs = _vector_to_raster_dask(
+        gdf.to_crs(like.crs),
+        gdf.size,
+        xlike=like.xdata,
+        field=field,
+        all_touched=all_touched,
+    )
+    return Raster(xrs)
+
+
+def rasterize_mask(gdf, like, all_touched=True):
+    """Convert vector data to a raster mask.
+
+    Parameters
+    ----------
+    like : Raster
+        A to use for grid and CRS information. The resulting raster will be
+        on the same grid as `like`.
+    all_touched : bool, optional
+        If ``True``, grid cells that the vector touches will be burned in.
+        If False, only cells with a center point inside of the vector
+        perimeter will be burned in.
+
+    Returns
+    -------
+    Raster
+        The resulting raster. The result will have a single band. All cells
+        that fall under the vector data are masked with ``1``. The null
+        value is 0.
+
+    """
+    like = get_raster(like)
+
+    xrs = _vector_to_raster_mask(
+        gdf.to_crs(like.crs).geometry, like, all_touched=all_touched
+    )
+    return Raster(xrs)
+
+
 def _normalize_geo_data(geo):
     if not _is_series(geo) and not _is_frame(geo):
         raise TypeError(
