@@ -14,7 +14,7 @@ from raster_tools.dtypes import F64, I64, is_int, is_str
 from raster_tools.raster import Raster, get_raster, xy_to_rowcol
 from raster_tools.vector import Vector, get_vector
 
-__all__ = ["ZONAL_STAT_FUNCS", "zonal_stats"]
+__all__ = ["ZONAL_STAT_FUNCS", "extract_points_eager", "zonal_stats"]
 
 
 def _nan_count(x):
@@ -526,6 +526,7 @@ def extract_points_eager(
     This function is partially eager. The x and y values for the target points
     are computed. The result is still a lazy dask DataFrame.
 
+
     This finds the grid cells that the points fall into and extracts the value
     at each point. The input feature will be partially computed to make sure
     that all of the geometries are points, unless `skip_validation` is set to
@@ -565,7 +566,10 @@ def extract_points_eager(
     ):
         raise TypeError("All geometries must be points.")
 
-    gdf = points.to_crs(raster.crs).data
+    if raster.crs is not None and raster.crs != points.crs:
+        gdf = points.to_crs(raster.crs).data
+    else:
+        gdf = points.data
     x = gdf.geometry.x.to_dask_array()
     y = gdf.geometry.y.to_dask_array()
     r, c = raster.index(*dask.compute(x, y))
